@@ -5,11 +5,12 @@
 # Licensed under the MIT License.
 
 from .common_note import Note
+from . import validstrings
 from ...exception import *
 
 
 class SceneControl(Note):
-    def __init__(self, time: int, scenetype: str, x: float = None, y: int = None):
+    def __init__(self, time: int, scenetype: str, x: float = 0, y: int = 0):
         super(SceneControl, self).__init__(time)
         self.scenetype: str = scenetype
         self.x: float = x
@@ -23,3 +24,11 @@ class SceneControl(Note):
                 int(self.time), self.scenetype, self.x, int(self.y))
         else:
             raise AffSceneTypeError('{0} is not a valid scene type'.format(self.scenetype))
+
+    def __setattr__(self, key, value):
+        super(SceneControl, self).__setattr__(key, value)
+        if key == 'scenetype':
+            if value not in validstrings.scenetypelist:
+                raise AffNoteValueError('invalid value {} for attribute "scenetype" (only accept {})'.format(
+                    value, str(validstrings.scenetypelist)
+                ))
